==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerStatusFluentImpl<A extends ContainerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStatusFluent<A> {

    private String containerID;
    private String image;
    private String imageID;
    private ContainerStateBuilder lastState;
    private String name;
    private Boolean ready;
    private Integer restartCount;
    private Boolean started;
    private ContainerStateBuilder state;

    public ContainerStatusFluentImpl() {
    }

    public ContainerStatusFluentImpl(ContainerStatus instance) {
        this.withContainerID(instance.getContainerID()); 
        this.withImage(instance.getImage()); 
        this.withImageID(instance.getImageID()); 
        this.withLastState(instance.getLastState()); 
        this.withName(instance.getName()); 
        this.withReady(instance.getReady()); 
        this.withRestartCount(instance.getRestartCount()); 
        this.withStarted(instance.getStarted()); 
        this.withState(instance.getState()); 
    }

    public String getContainerID() {
        return this.containerID;
    }

    public A withContainerID(String containerID) {
        this.containerID=containerID; return (A) this;
    }

    public Boolean hasContainerID() {
        return this.containerID != null;
    }

    public A withNewContainerID(StringBuilder arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(int[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(char[] arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(StringBuffer arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(byte[] arg1,int arg2) {
        return (A)withContainerID(new String(arg1, arg2));
    }

    public A withNewContainerID(byte[] arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(char[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(byte[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withContainerID(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewContainerID(String arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public String getImage() {
        return this.image;
    }

    public A withImage(String image) {
        this.image=image; return (A) this;
    }

    public Boolean hasImage() {
        return this.image != null;
    }

    public A withNewImage(StringBuilder arg1) {
        return (A)withImage(new String(arg1));
    }

    public A withNewImage(int[] arg1,int arg2,int arg3) {
        return (A)withImage(new String(arg1, arg2, arg3));
    }

    public A withNewImage(char[] arg1) {
        return (A)withImage(new String(arg1));
    }

    public A withNewImage(StringBuffer arg1) {
        return (A)withImage(new String(arg1));
    }

    public A withNewImage(byte[] arg1,int arg2) {
        return (A)withImage(new String(arg1, arg2));
    }

    public A withNewImage(byte[] arg1) {
        return (A)withImage(new String(arg1));
    }

    public A withNewImage(char[] arg1,int arg2,int arg3) {
        return (A)withImage(new String(arg1, arg2, arg3));
    }

    public A withNewImage(byte[] arg1,int arg2,int arg3) {
        return (A)withImage(new String(arg1, arg2, arg3));
    }

    public A withNewImage(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withImage(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewImage(String arg1) {
        return (A)withImage(new String(arg1));
    }

    public String getImageID() {
        return this.imageID;
    }

    public A withImageID(String imageID) {
        this.imageID=imageID; return (A) this;
    }

    public Boolean hasImageID() {
        return this.imageID != null;
    }

    public A withNewImageID(StringBuilder arg1) {
        return (A)withImageID(new String(arg1));
    }

    public A withNewImageID(int[] arg1,int arg2,int arg3) {
        return (A)withImageID(new String(arg1, arg2, arg3));
    }

    public A withNewImageID(char[] arg1) {
        return (A)withImageID(new String(arg1));
    }

    public A withNewImageID(StringBuffer arg1) {
        return (A)withImageID(new String(arg1));
    }

    public A withNewImageID(byte[] arg1,int arg2) {
        return (A)withImageID(new String(arg1, arg2));
    }

    public A withNewImageID(byte[] arg1) {
        return (A)withImageID(new String(arg1));
    }

    public A withNewImageID(char[] arg1,int arg2,int arg3) {
        return (A)withImageID(new String(arg1, arg2, arg3));
    }

    public A withNewImageID(byte[] arg1,int arg2,int arg3) {
        return (A)withImageID(new String(arg1, arg2, arg3));
    }

    public A withNewImageID(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withImageID(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewImageID(String arg1) {
        return (A)withImageID(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildLastState instead.
 * @return The buildable object.
 */
@Deprecated public ContainerState getLastState() {
        return this.lastState!=null?this.lastState.build():null;
    }

    public ContainerState buildLastState() {
        return this.lastState!=null?this.lastState.build():null;
    }

    public A withLastState(ContainerState lastState) {
        _visitables.get("lastState").remove(this.lastState);
        if (lastState!=null){ this.lastState= new ContainerStateBuilder(lastState); _visitables.get("lastState").add(this.lastState);} return (A) this;
    }

    public Boolean hasLastState() {
        return this.lastState != null;
    }

    public ContainerStatusFluent.LastStateNested<A> withNewLastState() {
        return new LastStateNestedImpl();
    }

    public ContainerStatusFluent.LastStateNested<A> withNewLastStateLike(ContainerState item) {
        return new LastStateNestedImpl(item);
    }

    public ContainerStatusFluent.LastStateNested<A> editLastState() {
        return withNewLastStateLike(getLastState());
    }

    public ContainerStatusFluent.LastStateNested<A> editOrNewLastState() {
        return withNewLastStateLike(getLastState() != null ? getLastState(): new ContainerStateBuilder().build());
    }

    public ContainerStatusFluent.LastStateNested<A> editOrNewLastStateLike(ContainerState item) {
        return withNewLastStateLike(getLastState() != null ? getLastState(): item);
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(int[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(char[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(byte[] arg1,int arg2) {
        return (A)withName(new String(arg1, arg2));
    }

    public A withNewName(byte[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(char[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public Boolean getReady() {
        return this.ready;
    }

    public A withReady(Boolean ready) {
        this.ready=ready; return (A) this;
    }

    public Boolean hasReady() {
        return this.ready != null;
    }

    public A withNewReady(String arg1) {
        return (A)withReady(new Boolean(arg1));
    }

    public A withNewReady(boolean arg1) {
        return (A)withReady(new Boolean(arg1));
    }

    public Integer getRestartCount() {
        return this.restartCount;
    }

    public A withRestartCount(Integer restartCount) {
        this.restartCount=restartCount; return (A) this;
    }

    public Boolean hasRestartCount() {
        return this.restartCount != null;
    }

    public A withNewRestartCount(int arg1) {
        return (A)withRestartCount(new Integer(arg1));
    }

    public Boolean getStarted() {
        return this.started;
    }

    public A withStarted(Boolean started) {
        this.started=started; return (A) this;
    }

    public Boolean hasStarted() {
        return this.started != null;
    }

    public A withNewStarted(String arg1) {
        return (A)withStarted(new Boolean(arg1));
    }

    public A withNewStarted(boolean arg1) {
        return (A)withStarted(new Boolean(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildState instead.
 * @return The buildable object.
 */
@Deprecated public ContainerState getState() {
        return this.state!=null?this.state.build():null;
    }

    public ContainerState buildState() {
        return this.state!=null?this.state.build():null;
    }

    public A withState(ContainerState state) {
        _visitables.get("state").remove(this.state);
        if (state!=null){ this.state= new ContainerStateBuilder(state); _visitables.get("state").add(this.state);} return (A) this;
    }

    public Boolean hasState() {
        return this.state != null;
    }

    public ContainerStatusFluent.StateNested<A> withNewState() {
        return new StateNestedImpl();
    }

    public ContainerStatusFluent.StateNested<A> withNewStateLike(ContainerState item) {
        return new StateNestedImpl(item);
    }

    public ContainerStatusFluent.StateNested<A> editState() {
        return withNewStateLike(getState());
    }

    public ContainerStatusFluent.StateNested<A> editOrNewState() {
        return withNewStateLike(getState() != null ? getState(): new ContainerStateBuilder().build());
    }

    public ContainerStatusFluent.StateNested<A> editOrNewStateLike(ContainerState item) {
        return withNewStateLike(getState() != null ? getState(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerStatusFluentImpl that = (ContainerStatusFluentImpl) o;
        if (containerID != null ? !containerID.equals(that.containerID) :that.containerID != null) return false;
        if (image != null ? !image.equals(that.image) :that.image != null) return false;
        if (imageID != null ? !imageID.equals(that.imageID) :that.imageID != null) return false;
        if (lastState != null ? !lastState.equals(that.lastState) :that.lastState != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (ready != null ? !ready.equals(that.ready) :that.ready != null) return false;
        if (restartCount != null ? !restartCount.equals(that.restartCount) :that.restartCount != null) return false;
        if (started != null ? !started.equals(that.started) :that.started != null) return false;
        if (state != null ? !state.equals(that.state) :that.state != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(containerID,  image,  imageID,  lastState,  name,  ready,  restartCount,  started,  state,  super.hashCode());
    }

    public class LastStateNestedImpl<N> extends ContainerStateFluentImpl<ContainerStatusFluent.LastStateNested<N>> implements ContainerStatusFluent.LastStateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ContainerStateBuilder builder;

            LastStateNestedImpl(ContainerState item) {
                this.builder = new ContainerStateBuilder(this, item);
                        
            }

            LastStateNestedImpl() {
                this.builder = new ContainerStateBuilder(this);
                        
            }

            public N and() {
                return (N) ContainerStatusFluentImpl.this.withLastState(builder.build());
            }

            public N endLastState() {
                return and();
            }
    }


    public class StateNestedImpl<N> extends ContainerStateFluentImpl<ContainerStatusFluent.StateNested<N>> implements ContainerStatusFluent.StateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ContainerStateBuilder builder;

            StateNestedImpl(ContainerState item) {
                this.builder = new ContainerStateBuilder(this, item);
                        
            }

            StateNestedImpl() {
                this.builder = new ContainerStateBuilder(this);
                        
            }

            public N and() {
                return (N) ContainerStatusFluentImpl.this.withState(builder.build());
            }

            public N endState() {
                return and();
            }
    }


}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerStatusFluentImpl<A extends ContainerStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerStatusFluent<A> {

    private String containerID;
    private String image;
    private String imageID;
    private ContainerStateBuilder lastState;
    private String name;
    private Boolean ready;
    private Integer restartCount;
    private Boolean started;
    private ContainerStateBuilder state;

    public ContainerStatusFluentImpl() {
    }

    public ContainerStatusFluentImpl(ContainerStatus instance) {
        this.withContainerID(instance.getContainerID()); 
        this.withImage(instance.getImage()); 
        this.withImageID(instance.getImageID()); 
        this.withLastState(instance.getLastState()); 
        this.withName(instance.getName()); 
        this.withReady(instance.getReady()); 
        this.withRestartCount(instance.getRestartCount()); 
        this.withStarted(instance.getStarted()); 
        this.withState(instance.getState()); 
    }

    public String getContainerID() {
        return this.containerID;
    }

    public A withContainerID(String containerID) {
        this.containerID=containerID; return (A) this;
    }

    public Boolean hasContainerID() {
        return this.containerID != null;
    }

    public A withNewContainerID(StringBuilder arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(int[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(char[] arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(StringBuffer arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(byte[] arg1,int arg2) {
        return (A)withContainerID(new String(arg1, arg2));
    }

    public A withNewContainerID(byte[] arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public A withNewContainerID(char[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(byte[] arg1,int arg2,int arg3) {
        return (A)withContainerID(new String(arg1, arg2, arg3));
    }

    public A withNewContainerID(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withContainerID(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewContainerID(String arg1) {
        return (A)withContainerID(new String(arg1));
    }

    public String getImage() {
        return this.image;
    }

    public A withImage(String image) {
        this.image=image; return (A) this;
    }

    public Boolean hasImage() {
        return this.image != null;
    }

    public A withNewImage(StringBuilder arg1) {
        return (A)withImage(new String(arg1));
    }

    public A withNewImage(int[] arg1,int arg2,int arg3) {
        return (A)withImage(new String(arg1, arg2, arg3));
    }

    public A withNewImage(char[] arg1) {
        return (A)withImage(new String(arg1));
    }

    public A withNewImage(StringBuffer arg1) {
        return (A)withImage(new String(arg1));
    }

    public A withNewImage(byte[] arg1,int arg2) {
        return (A)withImage(new String(arg1, arg2));
    }

    public A withNewImage(byte[] arg1) {
        return (A)withImage(new String(arg1));
    }

    public A withNewImage(char[] arg1,int arg2,int arg3) {
        return (A)withImage(new String(arg1, arg2, arg3));
    }

    public A withNewImage(byte[] arg1,int arg2,int arg3) {
        return (A)withImage(new String(arg1, arg2, arg3));
    }

    public A withNewImage(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withImage(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewImage(String arg1) {
        return (A)withImage(new String(arg1));
    }

    public String getImageID() {
        return this.imageID;
    }

    public A withImageID(String imageID) {
        this.imageID=imageID; return (A) this;
    }

    public Boolean hasImageID() {
        return this.imageID != null;
    }

    public A withNewImageID(StringBuilder arg1) {
        return (A)withImageID(new String(arg1));
    }

    public A withNewImageID(int[] arg1,int arg2,int arg3) {
        return (A)withImageID(new String(arg1, arg2, arg3));
    }

    public A withNewImageID(char[] arg1) {
        return (A)withImageID(new String(arg1));
    }

    public A withNewImageID(StringBuffer arg1) {
        return (A)withImageID(new String(arg1));
    }

    public A withNewImageID(byte[] arg1,int arg2) {
        return (A)withImageID(new String(arg1, arg2));
    }

    public A withNewImageID(byte[] arg1) {
        return (A)withImageID(new String(arg1));
    }

    public A withNewImageID(char[] arg1,int arg2,int arg3) {
        return (A)withImageID(new String(arg1, arg2, arg3));
    }

    public A withNewImageID(byte[] arg1,int arg2,int arg3) {
        return (A)withImageID(new String(arg1, arg2, arg3));
    }

    public A withNewImageID(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withImageID(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewImageID(String arg1) {
        return (A)withImageID(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildLastState instead.
 * @return The buildable object.
 */
@Deprecated public ContainerState getLastState() {
        return this.lastState!=null?this.lastState.build():null;
    }

    public ContainerState buildLastState() {
        return this.lastState!=null?this.lastState.build():null;
    }

    public A withLastState(ContainerState lastState) {
        _visitables.get("lastState").remove(this.lastState);
        if (lastState!=null){ this.lastState= new ContainerStateBuilder(lastState); _visitables.get("lastState").add(this.lastState);} return (A) this;
    }

    public Boolean hasLastState() {
        return this.lastState != null;
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.LastStateNested<A> withNewLastState() {
        return new LastStateNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.LastStateNested<A> withNewLastStateLike(ContainerState item) {
        return new LastStateNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.LastStateNested<A> editLastState() {
        return withNewLastStateLike(getLastState());
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.LastStateNested<A> editOrNewLastState() {
        return withNewLastStateLike(getLastState() != null ? getLastState(): new ContainerStateBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.LastStateNested<A> editOrNewLastStateLike(ContainerState item) {
        return withNewLastStateLike(getLastState() != null ? getLastState(): item);
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(int[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(char[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(byte[] arg1,int arg2) {
        return (A)withName(new String(arg1, arg2));
    }

    public A withNewName(byte[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(char[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public Boolean getReady() {
        return this.ready;
    }

    public A withReady(Boolean ready) {
        this.ready=ready; return (A) this;
    }

    public Boolean hasReady() {
        return this.ready != null;
    }

    public A withNewReady(String arg1) {
        return (A)withReady(new Boolean(arg1));
    }

    public A withNewReady(boolean arg1) {
        return (A)withReady(new Boolean(arg1));
    }

    public Integer getRestartCount() {
        return this.restartCount;
    }

    public A withRestartCount(Integer restartCount) {
        this.restartCount=restartCount; return (A) this;
    }

    public Boolean hasRestartCount() {
        return this.restartCount != null;
    }

    public A withNewRestartCount(int arg0) {
        return (A)withRestartCount(new Integer(arg0));
    }

    public Boolean getStarted() {
        return this.started;
    }

    public A withStarted(Boolean started) {
        this.started=started; return (A) this;
    }

    public Boolean hasStarted() {
        return this.started != null;
    }

    public A withNewStarted(String arg1) {
        return (A)withStarted(new Boolean(arg1));
    }

    public A withNewStarted(boolean arg1) {
        return (A)withStarted(new Boolean(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildState instead.
 * @return The buildable object.
 */
@Deprecated public ContainerState getState() {
        return this.state!=null?this.state.build():null;
    }

    public ContainerState buildState() {
        return this.state!=null?this.state.build():null;
    }

    public A withState(ContainerState state) {
        _visitables.get("state").remove(this.state);
        if (state!=null){ this.state= new ContainerStateBuilder(state); _visitables.get("state").add(this.state);} return (A) this;
    }

    public Boolean hasState() {
        return this.state != null;
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.StateNested<A> withNewState() {
        return new StateNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.StateNested<A> withNewStateLike(ContainerState item) {
        return new StateNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.StateNested<A> editState() {
        return withNewStateLike(getState());
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.StateNested<A> editOrNewState() {
        return withNewStateLike(getState() != null ? getState(): new ContainerStateBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.ContainerStatusFluent.StateNested<A> editOrNewStateLike(ContainerState item) {
        return withNewStateLike(getState() != null ? getState(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerStatusFluentImpl that = (ContainerStatusFluentImpl) o;
        if (containerID != null ? !containerID.equals(that.containerID) :that.containerID != null) return false;
        if (image != null ? !image.equals(that.image) :that.image != null) return false;
        if (imageID != null ? !imageID.equals(that.imageID) :that.imageID != null) return false;
        if (lastState != null ? !lastState.equals(that.lastState) :that.lastState != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (ready != null ? !ready.equals(that.ready) :that.ready != null) return false;
        if (restartCount != null ? !restartCount.equals(that.restartCount) :that.restartCount != null) return false;
        if (started != null ? !started.equals(that.started) :that.started != null) return false;
        if (state != null ? !state.equals(that.state) :that.state != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(containerID,  image,  imageID,  lastState,  name,  ready,  restartCount,  started,  state,  super.hashCode());
    }

    public class LastStateNestedImpl<N> extends ContainerStateFluentImpl<io.fabric8.kubernetes.api.model.ContainerStatusFluent.LastStateNested<N>> implements io.fabric8.kubernetes.api.model.ContainerStatusFluent.LastStateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ContainerStateBuilder builder;

            LastStateNestedImpl(ContainerState item) {
                this.builder = new ContainerStateBuilder(this, item);
                        
            }

            LastStateNestedImpl() {
                this.builder = new ContainerStateBuilder(this);
                        
            }

            public N and() {
                return (N) ContainerStatusFluentImpl.this.withLastState(builder.build());
            }

            public N endLastState() {
                return and();
            }
    }


    public class StateNestedImpl<N> extends ContainerStateFluentImpl<io.fabric8.kubernetes.api.model.ContainerStatusFluent.StateNested<N>> implements io.fabric8.kubernetes.api.model.ContainerStatusFluent.StateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final ContainerStateBuilder builder;

            StateNestedImpl(ContainerState item) {
                this.builder = new ContainerStateBuilder(this, item);
                        
            }

            StateNestedImpl() {
                this.builder = new ContainerStateBuilder(this);
                        
            }

            public N and() {
                return (N) ContainerStatusFluentImpl.this.withState(builder.build());
            }

            public N endState() {
                return and();
            }
    }


}
